@@ -5,7 +5,6 @@ from copy import copy
 from datetime import datetime
 from typing import Any, Dict, List, Text, Tuple
 
-from prettytable import PrettyTable
 from rich.console import Console
 from rich.progress import track
 from rich.table import Table
@@ -193,17 +192,18 @@ async def delete_project(project_id: Text) -> Dict[Text, Any]:
 
 def print_projects_table(projects: Dict[Text, Any], verbose: bool):
     table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
-    table.add_column("Project Name", style="#c47900")
-    table.add_column("Project ID", style="#c47900")
-    table.add_column("Languages", style="#c47900")
+    table.add_column("Project Name")
+    table.add_column("Project ID")
     if verbose:
-        table.add_column("Number of Examples", style="#c47900")
-        table.add_column("Number of Intents", style="#c47900")
-        table.add_column("Number of Models", style="#c47900")
+        table.add_column("Languages")
+        table.add_column("Number of Examples")
+        table.add_column("Number of Intents")
+        table.add_column("Number of Models")
     for data in projects[DATA][PROJECTS]:
-        args = [data[PROJECT_NAME], data[PROJECT_ID], ", ".join(data[LANGUAGE])]
+        args = [data[PROJECT_NAME], data[PROJECT_ID]]
         if verbose:
             args += [
+                ", ".join(data[LANGUAGE]),
                 str(data[NUMBER_OF_EXAMPLES]),
                 str(data[NUMBER_OF_INTENTS]),
                 str(data[NUMBER_OF_MODELS]),
@@ -212,30 +212,6 @@ def print_projects_table(projects: Dict[Text, Any], verbose: bool):
     console.print(table)
 
 
-def train_table(projects: Dict[Text, Any]):
-    table = PrettyTable()
-    table.field_names = [
-        "Project Name",
-        "Project ID",
-        "Number of Examples",
-        "Number of Intents",
-        "number of Models",
-        "Languages",
-    ]
-    for data in projects[DATA][PROJECTS]:
-        table.add_row(
-            [
-                data[PROJECT_NAME],
-                data[PROJECT_ID],
-                data[NUMBER_OF_EXAMPLES],
-                data[NUMBER_OF_INTENTS],
-                data[NUMBER_OF_MODELS],
-                data[LANGUAGE],
-            ]
-        )
-    console.print(f"\n{table}")
-
-
 async def list_projects(
     search: Text, page_size: int, page_number: int, languages: List[Text], verbose: bool
 ) -> Dict[Text, Any]:
@@ -267,19 +243,19 @@ async def list_projects(
 
 def print_examples_table(examples: Dict[Text, Any], verbose: bool = False):
     table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
-    table.add_column("Example ID", style="#c47900")
-    table.add_column("Text", style="#c47900")
-    table.add_column("Intent", style="#c47900")
+    table.add_column("Example ID")
+    table.add_column("Text")
     if verbose:
+        table.add_column("Intent")
         table.add_column("N Entities", style="#c47900")
 
     console.print(
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Examples Count: {examples[DATA][COUNT]}"
     )
     for data in examples[DATA][EXAMPLES]:
-        args = [data[EXAMPLE_ID], data[TEXT], data[INTENT]]
+        args = [data[EXAMPLE_ID], data[TEXT]]
         if verbose:
-            args.append(str(len(data[ENTITIES])))
+            args += [data[INTENT], str(len(data[ENTITIES]))]
         table.add_row(*args)
 
     console.print(table)
@@ -350,28 +326,25 @@ def get_training_status_colour(status: Text) -> Text:
 
 def print_models_table(models: Dict[Text, Any], verbose: bool):
     table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
-    table.add_column("Model ID", style="#c47900")
-    table.add_column("Model Name", style="#c47900")
-    table.add_column("Training Status", style="#c47900")
+    table.add_column("Model ID")
+    table.add_column("Model Name")
     if verbose:
-        table.add_column("Replicas", style="#c47900")
-        table.add_column("Intent Acc", style="#c47900")
-        table.add_column("Entity Acc", style="#c47900")
-        table.add_column("Training Time (sec)", style="#c47900")
-        table.add_column("Last Updated", style="#c47900")
+        table.add_column("Training Status")
+        table.add_column("Replicas")
+        table.add_column("Intent Acc")
+        table.add_column("Entity Acc")
+        table.add_column("Training Time (sec)")
+        table.add_column("Last Updated")
 
     console.print(f"> Total Models Count: {models[DATA][COUNT]}")
     console.print(
         f" [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Models Count: {models[DATA][COUNT]}"
     )
     for data in models[DATA][MODELS]:
-        args = [
-            data[MODEL_ID],
-            data[MODEL_NAME],
-            f"{get_training_status_colour(data[TRAINING_STATUS])} {data[TRAINING_STATUS]}",
-        ]
+        args = [data[MODEL_ID], data[MODEL_NAME]]
         if verbose:
             args += [
+                f"{get_training_status_colour(data[TRAINING_STATUS])} {data[TRAINING_STATUS]}",
                 str(data[REPLICAS]),
                 "{:.3f}".format(
                     data[METRICS][INTENT_CLASSIFIER_METRICS][INTENT_ACCURACY]
@@ -657,10 +630,10 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
 
 def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
-    table.add_column("Text", style="#c47900")
-    table.add_column("Intent", style="#c47900")
-    table.add_column("Intent Confidence", style="#c47900")
-    table.add_column("Response Time (sec)", style="#c47900")
+    table.add_column("Text")
+    table.add_column("Intent")
+    table.add_column("Intent Confidence")
+    table.add_column("Response Time (sec)")
     table.add_row(
         nlu_response[DATA]["text"][:30] + "[...]",
         nlu_response[DATA]["intent"]["name"],
@@ -671,8 +644,8 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     intent_ranking_table = Table(
         show_header=True, header_style="bold #c47900", show_lines=True
     )
-    table.add_column("Intent", style="#c47900")
-    table.add_column("Confidence", style="#c47900")
+    table.add_column("Intent")
+    table.add_column("Confidence")
 
     for row in nlu_response[DATA]["intent_ranking"]:
         intent_ranking_table.add_row(
